@@ -233,15 +233,24 @@ class NDCubeBase(NDCubeSlicingMixin, NDCubeABC):
                 # Find keys in wcs_ivoa_mapping dict that represent start of CTYPE.
                 # Ensure CTYPE is capitalized.
                 keys = list(filter(lambda key: ctype[i].upper().startswith(key), wcs_ivoa_mapping))
+                # Assuming CTYPE is supported by wcs_ivoa_mapping, use its corresponding axis name.
+                if len(keys) == 1:
+                    axis_name = wcs_ivoa_mapping.get(keys[0])
+                # If CTYPE not supported, raise a warning and set the axis name to CTYPE.
+                elif len(keys) == 0:
+                    warnings.warn("CTYPE not recognized by ndcube. "
+                                  "Please raise an issue at "
+                                  "https://github.com/sunpy/ndcube/issues citing the "
+                                  "unsupported CTYPE as we'll include it: "
+                                  "CTYPE = {0}".format(ctype[i]))
+                    axis_name = "custom:{0}".format(ctype[i])
                 # If there are multiple valid keys, raise an error.
-                if len(keys) != 1:
+                else:
                     raise ValueError("Non-unique CTYPE key.  Please raise an issue at "
-                                     "https://github.com/sunpy/ndcube/issues citing the"
+                                     "https://github.com/sunpy/ndcube/issues citing the "
                                      "following  CTYPE and non-unique keys: "
                                      "CTYPE = {0}; keys = {1}".format(ctype[i], keys))
-                else:
-                    key = keys[0]
-                axes_ctype.append(wcs_ivoa_mapping.get(key, default=None))
+                axes_ctype.append(axis_name)
         return tuple(axes_ctype[::-1])
 
     def pixel_to_world(self, *quantity_axis_list):
